# 3. Use same colour for all headers

Date: 2018-09-09

## Status

Superseded by [4. Distinguish superseded records with colour](0004-distinguish-superseded-records-with-colour.md)

## Context

`adr-viewer` presents all records with the same `lightgreen` header, even though records may be in different states.

## Decision

We will keep the `lightgreen` colour for everything

## Consequences

No work necessary to support ADRs superceding eachother.
